@@ -241,7 +241,7 @@ foreach ($security_blocked_ips as $security_block) {
         if ($service_block['ip_address'] === $security_block['ip_address']) {
             $found_in_service = true;
             // If security manager block is newer or permanent, update the display
-            if ($security_block['block_time'] > $service_block['block_time'] || $security_block['unblock_time'] == 0) {
+            if ($security_block['block_time'] > $service_block['block_time'] || $security_block['unblock_time'] == -1) {
                 $service_block['reason'] = $security_block['reason'];
                 $service_block['blocking_service'] = 'security_manager';
                 $service_block['block_time'] = $security_block['block_time'];
@@ -859,8 +859,8 @@ if (!empty($service_blocked_ips)): ?>
                                 <td>
                                     <?php 
                                     // Check if this is a permanent block
-                                    if ($blocked['unblock_time'] == 0 || $blocked['unblock_time'] == 4102444799) {
-                                        // Permanent block (0 or year 2099)
+                                    if ($blocked['unblock_time'] == -1 || $blocked['unblock_time'] == 4102444799) {
+                                        // Permanent block (-1 or year 2099)
                                         echo '<small class="text-danger"><strong>Permanent</strong></small>';
                                     } else {
                                         $time_left = $blocked['unblock_time'] - time();
